@@ -1,8 +1,13 @@
+'use strict';
+
 const set = require('object-path-set');
 
-module.exports = function(obj, path, value) {
+module.exports = (obj, path, value) => {
   try {
     set(obj, path, value);
-  } catch (err) {}
+  } catch (err) {
+    // do nothing
+  }
   return obj;
 };
+
